"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.listAllActions = listAllActions;
exports.listInvalidActions = listInvalidActions;
exports.default = validate;

var _propTypes = require("prop-types");

var _propTypes2 = _interopRequireDefault(_propTypes);

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function listAllActions(rules) {
  var allActions = rules.map(function (_ref) {
    var type = _ref.event.type;
    return type;
  });
  return new Set(allActions);
}

function listInvalidActions(rules, actions) {
  var ruleActions = listAllActions(rules);
  Object.keys(actions).forEach(function (a) {
    return ruleActions.delete(a);
  });
  return Array.from(ruleActions);
}

function validateInvalidAction(rules, actions) {
  var invalidActions = listInvalidActions(rules, actions);
  if (invalidActions.length !== 0) {
    (0, _utils.toError)("Rule contains invalid action \"" + invalidActions + "\"");
  }
}

function validateInvalidParams(rules, actions, schema, uiSchema) {
  rules.map(function (_ref2) {
    var _ref2$event = _ref2.event,
        type = _ref2$event.type,
        params = _ref2$event.params;

    var actionPropTypes = actions[type].propTypes;
    if (actionPropTypes !== undefined && actionPropTypes !== null) {
      _propTypes2.default.checkPropTypes(actionPropTypes, params, "prop", type);
    }

    var actionValidation = actions[type].validate;
    if (actionValidation && typeof actionValidation === "function") {
      actionValidation(params, schema, uiSchema);
    }
  });
}

function validate(rules, actions, schema, uiSchema) {
  validateInvalidAction(rules, actions);
  validateInvalidParams(rules, actions, schema, uiSchema);
}